smart_collect: Smart collect with size awareness

View source: R/utils.R

smart_collectR Documentation

Smart collect with size awareness

Description

Internal function that collects a lazy table with warnings for large queries.

Usage

smart_collect(tbl, wrds, lazy = FALSE)

Arguments

tbl

A tbl_lazy object from dbplyr.

wrds

Database connection for row counting.

lazy

If TRUE, return the lazy table without collecting.

Value

A tibble if collecting, or the lazy table if lazy = TRUE.


wrds documentation built on May 11, 2026, 5:06 p.m.