| link_ibes_crsp | R Documentation |
Downloads the WRDS-provided linking table that maps IBES tickers to CRSP PERMNOs with valid date ranges and match quality scores.
link_ibes_crsp(wrds, max_score = 5L, n = Inf, lazy = FALSE)
wrds |
A |
max_score |
Maximum match quality score to include. Defaults to better matches:
|
n |
Maximum number of rows to return. Defaults to |
lazy |
If |
The linking table comes from wrdsapps_link_crsp_ibes.ibcrsphist.
To use the link, join on ticker and ensure your observation date falls
within the sdate to edate range.
A tibble with columns:
IBES ticker
CRSP permanent security identifier
Start date of the link
End date of the link
Match quality score (1 = best, 6 = worst)
WRDS IBES-CRSP Linking Table Documentation: https://wrds-www.wharton.upenn.edu/documents/796/IBES_CRSP_Linking_Table_by_WRDS.pdf
link_ccm()
## Not run:
wrds <- wrds_connect()
ibes_link <- link_ibes_crsp(wrds)
# Join with IBES data on ticker and date range
ibes_data |>
dplyr::inner_join(ibes_link, by = dplyr::join_by(ticker)) |>
dplyr::filter(date >= sdate, date <= edate)
wrds_disconnect(wrds)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.