Learn R Programming

wrds (version 0.0.1)

smart_collect: Smart collect with size awareness

Description

Internal function that collects a lazy table with warnings for large queries.

Usage

smart_collect(tbl, wrds, lazy = FALSE)

Value

A tibble if collecting, or the lazy table if lazy = TRUE.

Arguments

tbl

A tbl_lazy object from dbplyr.

wrds

Database connection for row counting.

lazy

If TRUE, return the lazy table without collecting.