| wrds_connect | R Documentation |
Establishes a connection to the WRDS PostgreSQL server using credentials stored securely in the system keyring.
wrds_connect(user_key = "wrds_user", password_key = "wrds_pw", keyring = NULL)
user_key |
Name of the keyring entry storing the WRDS username.
Defaults to |
password_key |
Name of the keyring entry storing the WRDS password.
Defaults to |
keyring |
Optional keyring name. If |
Credentials must be set up before first use with wrds_set_credentials().
The connection uses bigint = "numeric" so that 64-bit integers from
PostgreSQL are returned as doubles, which avoids overflow and works
well with tidyverse functions.
A DBIConnection object for the WRDS PostgreSQL database.
wrds_disconnect(), wrds_set_credentials()
## Not run:
wrds <- wrds_connect()
list_subscriptions(wrds)
wrds_disconnect(wrds)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.