Learn R Programming

wrds (version 0.0.1)

wrds_connect: Connect to WRDS

Description

Establishes a connection to the WRDS PostgreSQL server using credentials stored securely in the system keyring.

Usage

wrds_connect(user_key = "wrds_user", password_key = "wrds_pw", keyring = NULL)

Value

A DBIConnection object for the WRDS PostgreSQL database.

Arguments

user_key

Name of the keyring entry storing the WRDS username. Defaults to "wrds_user".

password_key

Name of the keyring entry storing the WRDS password. Defaults to "wrds_pw".

keyring

Optional keyring name. If NULL (default), uses the default keyring.

Details

Credentials must be set up before first use with wrds_set_credentials(). The connection uses bigint = "integer" for compatibility with R's integer type.

See Also

wrds_disconnect(), wrds_set_credentials()

Examples

Run this code
if (FALSE) {
wrds <- wrds_connect()
list_libraries(wrds)
wrds_disconnect(wrds)
}

Run the code above in your browser using DataLab